Package: covtracer
Title: Contextualizing Tests
Version: 0.0.3
Authors@R: 
    c(
      person(
        "Doug", "Kelkhoff", , 
        "doug.kelkhoff@gmail.com", 
        role = c("aut"),
        comment = c(ORCID = "0009-0003-7845-4061")
      ),
      person(
        given = "Szymon",
        family = "Maksymiuk",
        role = c("aut", "cre"),
        email = "sz.maksymiuk@gmail.com",
        comment = c(ORCID = "0000-0002-3120-1601")
      ),
      person(
        given = "Andrew",
        family = "McNeil",
        role = c("aut"),
        email = "andrew.richard.mcneil@gmail.com"
      ),
      person(
	    "F. Hoffmann-La Roche AG", 
		role = c("cph", "fnd")
	  )
    )
Description: 
    Dissects a package environment or 'covr' coverage object in order to cross
    reference tested code with the lines that are evaluated, as well as linking
    those evaluated lines to the documentation that they are described within.
    Connecting these three pieces of information provides a mechanism of 
	linking tests to documented behaviors.
URL: https://github.com/genentech/covtracer
BugReports: https://github.com/genentech/covtracer/issues
Depends: R (>= 3.2.0)
Imports: tools, stats, methods
Suggests: testthat, covr (>= 3.5.2), withr, R6, cli, dplyr, igraph,
        knitr, rmarkdown
License: MIT + file LICENSE
Encoding: UTF-8
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-28 10:37:48 UTC; maksymis
Author: Doug Kelkhoff [aut] (ORCID: <https://orcid.org/0009-0003-7845-4061>),
  Szymon Maksymiuk [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3120-1601>),
  Andrew McNeil [aut],
  F. Hoffmann-La Roche AG [cph, fnd]
Maintainer: Szymon Maksymiuk <sz.maksymiuk@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-28 11:10:02 UTC
Built: R 4.5.2; ; 2026-07-28 11:35:24 UTC; unix
