Package: examplepkg
Title: Example package for covtracer demos
Version: 0.0.0.9000
Authors@R: 
    person(given = "First",
           family = "Last",
           role = c("aut", "cre"),
           email = "first.last@example.com",
           comment = c(ORCID = "YOUR-ORCID-ID"))
Description: Used as an example for covtracer demos.
Imports:
    R6,
    methods
License:
    Inheritted From Package `covtracer`
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE, r6 = FALSE)
RoxygenNote: 7.3.1
Suggests: 
    testthat (>= 3.0.0)
Config/testthat/edition: 3
