# Generated by roxygen2: do not edit by hand

S3method("[",list_of_srcref)
S3method(as.data.frame,list_of_srcref)
S3method(as.double,with_pseudo_srcref)
S3method(as_list_of_srcref,environment)
S3method(as_list_of_srcref,list)
S3method(format,list_of_srcref)
S3method(format,with_pseudo_srcref)
S3method(getSrcFilepath,default)
S3method(getSrcFilepath,list_of_srcref)
S3method(obj_namespace_name,R6ClassGenerator)
S3method(obj_namespace_name,character)
S3method(obj_namespace_name,default)
S3method(obj_namespace_name,nonstandardGenericFunction)
S3method(obj_namespace_name,standardGeneric)
S3method(pkg_srcrefs,character)
S3method(pkg_srcrefs,coverage)
S3method(pkg_srcrefs,environment)
S3method(print,list_of_srcref)
S3method(srcrefs,MethodDefinition)
S3method(srcrefs,R6ClassGenerator)
S3method(srcrefs,default)
S3method(srcrefs,environment)
S3method(srcrefs,list)
S3method(srcrefs,namespace)
S3method(srcrefs,nonstandardGenericFunction)
S3method(srcrefs,standardGeneric)
S3method(test_description,call)
S3method(test_description,character)
S3method(test_description,default)
S3method(test_description,expression)
S3method(test_description,list)
S3method(test_description,srcref)
S3method(test_srcrefs,coverage)
S3method(test_srcrefs_df,coverage)
S3method(test_trace_df,coverage)
S3method(trace_srcrefs,coverage)
export(Rd_df)
export(join_on_containing_srcrefs)
export(pkg_srcrefs)
export(pkg_srcrefs_df)
export(test_srcrefs)
export(test_srcrefs_df)
export(test_trace_df)
export(test_trace_mapping)
export(trace_srcrefs)
export(trace_srcrefs_df)
import(tools)
importFrom(methods,getPackageName)
importFrom(methods,packageSlot)
importFrom(stats,aggregate)
importFrom(utils,capture.output)
importFrom(utils,getSrcDirectory)
importFrom(utils,getSrcFilename)
importFrom(utils,getSrcref)
importFrom(utils,packageVersion)
importFrom(utils,tail)
