# Generated by roxygen2: do not edit by hand

export(Accumulator)
export(Person)
export(PersonPrime)
export(Rando)
export(S4Example)
export(S4Example2)
export(complex_call_stack)
export(deeper_nested_function)
export(help)
export(hypotenuse)
export(increment)
export(person)
export(rd_data_sampler)
export(rd_sampler)
export(reexport_example)
export(s3_example_func)
exportClasses(S4Example)
exportClasses(S4Example2)
exportMethods(increment)
import(methods)
importFrom(R6,R6Class)
importFrom(utils,example)
importFrom(utils,help)
importFrom(utils,person)
