#' Rd data sampler
#'
#' An example of dataset documentation
#'
#' @format A data.frame with 3 rows and 2 variables:
#' \describe{
#'   \item{x}{Numeric values}
#'   \item{y}{Character values}
#' }
#'
#' @source <r.d.sampler/>
#'
#' @docType data
#' @examples
#' rd_data_sampler
#'
#' @export
#'
rd_data_sampler <- data.frame(x = 1:3, y = letters[1:3])
