% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s4_example.R
\name{increment}
\alias{increment}
\title{Example S4 generic registered by a package}
\usage{
increment(x)
}
\arguments{
\item{x}{An x}
}
\description{
Example S4 generic registered by a package
}
