% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/r6_example.R
\name{adder}
\alias{adder}
\title{Helper function to test closures as R6 methods}
\usage{
adder(self)
}
\description{
Helper function to test closures as R6 methods
}
