% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reexports.R
\name{reexport_example}
\alias{reexport_example}
\title{Manually redefining a function from another package}
\usage{
reexport_example(
  topic,
  package = NULL,
  lib.loc = NULL,
  character.only = FALSE,
  give.lines = FALSE,
  local = FALSE,
  type = c("console", "html"),
  echo = TRUE,
  verbose = getOption("verbose"),
  setRNG = FALSE,
  ask = getOption("example.ask"),
  prompt.prefix = abbreviate(topic, 6),
  catch.aborts = FALSE,
  run.dontrun = FALSE,
  run.donttest = interactive()
)
}
\description{
Manually redefining a function from another package
}
